Crate i_slint_common

Crate i_slint_common 

This crate contains internal data structures and code that is shared between the i-slint-core and the i-slint-compiler crates.

NOTE: This library is an internal crate of the Slint project. This crate should not be used directly by applications using Slint. You should use the slint crate instead.

WARNING: This crate does not follow the semver convention for versioning and can only be used with version = "=x.y.z" in Cargo.toml.

Modules

builtin_structs
This module contains all builtin structures exposed in the .slint language.
enums
This module contains all enums exposed in the .slint language.
key_codes
This module is meant to be included by different crates and each crate must define the macro for_each_keys
styled_text

Macros

for_each_builtin_structs
Call a macro with every builtin structures exposed in the .slint language
for_each_enums
Call a macro with every enum exposed in the .slint language
for_each_keys

Constants

MENU_SEPARATOR_PLACEHOLDER_TITLE
MenuItem with this title are actually MenuSeparator
ROW_COL_AUTO
Internal “magic” value for row and col numbers, to mean “auto”, in GridLayoutInputData Use the value 65536, so it’s outside u16 range and not as likely as -1 (we can catch it as a literal at compile time, but not if it’s a runtime value)

Functions

get_native_style
Detect the native style depending on the platform